release_key

Function release_key 

pub fn release_key(
    key: Option<String>,
    run_id: RunId,
    key_gate: &mut KeyGate,
) -> LifecycleResult
Attempts to release the concurrency key for a run.

Returns LifecycleResult::Released if the key was held by the run. Returns LifecycleResult::NoAction if no key was defined or the key was not held by the run.