derive_once

Function derive_once 

pub fn derive_once(
    clock: &impl Clock,
    task_id: TaskId,
    already_derived: u32,
) -> Result<DerivationSuccess, DerivationError>
Derives exactly one run for a Once policy task.

If at least one run has already been derived, no new run is created.