DerivationSuccess

Struct DerivationSuccess 

pub struct DerivationSuccess { /* private fields */ }
Success result from run derivation.

Implementations

Source

impl DerivationSuccess

pub fn derived(&self) -> &[RunInstance]

Returns the newly derived run instances.

pub fn into_derived(self) -> Vec<RunInstance>

Consumes self and returns the newly derived run instances.

pub fn already_derived(&self) -> u32

Returns the total number of runs considered derived for the task after this call.