Module ready

Module ready 

Ready index - runs eligible to be leased.

The ready index holds run instances in the Ready state. These runs have passed their scheduled_at time and are eligible to be selected by the scheduler for leasing to an executor.

Structs

ReadyIndex
A view of all runs in the Ready state.