ReadyIndex

Struct ReadyIndex 

pub struct ReadyIndex { /* private fields */ }
A view of all runs in the Ready state.

This structure provides filtering and traversal over runs that are eligible to be leased. Runs transition from Ready to Leased (or Canceled) when selected by the scheduler.

Implementations

Source

impl ReadyIndex

pub fn new() -> Self

Creates a new empty ready index.

pub fn from_runs(runs: Vec<RunInstance>) -> Self

Creates a ready index from a vector of runs.

All runs must be in the Ready state.

pub fn runs(&self) -> &[RunInstance]

Returns all runs in the ready index.

pub fn len(&self) -> usize

Returns the number of runs in the ready index.

pub fn is_empty(&self) -> bool

Returns true if the index contains no runs.