pub struct RunningIndex { /* private fields */ }Expand description
A view of all active runs (Leased and Running).
This structure provides filtering and traversal over runs that are currently in-flight. Active runs transition from Running to either:
- RetryWait (on failure, if retries remain)
- Completed (on success)
- Failed (on failure, no retries remaining)
- Canceled
Implementations
Sourceimpl RunningIndex
impl RunningIndex
Sourcepub fn from_runs(runs: Vec<RunInstance>) -> Self
pub fn from_runs(runs: Vec<RunInstance>) -> Self
Creates a running index from a vector of runs.
All runs must be in the Leased or Running state.
Sourcepub fn runs(&self) -> &[RunInstance]
pub fn runs(&self) -> &[RunInstance]
Returns all runs in the running index.
Sourcepub fn leased(&self) -> Vec<&RunInstance>
pub fn leased(&self) -> Vec<&RunInstance>
Returns only leased runs.
Sourcepub fn executing(&self) -> Vec<&RunInstance>
pub fn executing(&self) -> Vec<&RunInstance>
Returns only currently executing runs.