Module scheduled

Module scheduled 

Scheduled index - runs waiting to become ready.

The scheduled index holds run instances in the Scheduled state. These runs are newly derived and waiting for their scheduled_at time to pass before they can transition to Ready.

Structs

ScheduledIndex
A view of all runs in the Scheduled state.