AcquireResult

Enum AcquireResult 

pub enum AcquireResult {
    Acquired(Lease),
    AlreadyLeased,
    WrongRunSlot {
        requested_run_id: RunId,
        existing_run_id: RunId,
    },
}
Result of a lease acquisition attempt.

Variants



Acquired(Lease)

Lease was successfully acquired.



AlreadyLeased

Lease acquisition failed because the run already has an active lease.



WrongRunSlot

Lease acquisition failed because the provided lease slot belongs to a different run than requested.

Fields

requested_run_id: RunId

Run id requested by this acquisition attempt.

existing_run_id: RunId

Run id currently occupying the provided lease slot.