SelectionResult

Struct SelectionResult 

pub struct SelectionResult { /* private fields */ }
Result of running the default selector.

This structure contains the runs that should be selected (leased) from the ready index, in the order they should be selected.

Implementations

Source

impl SelectionResult

pub fn selected(&self) -> &[RunInstance]

Returns the runs selected for leasing, in order.

pub fn into_selected(self) -> Vec<RunInstance>

Consumes self and returns the selected runs.

pub fn remaining(&self) -> &[RunInstance]

Returns the runs remaining in the ready index after selection.