pub struct DerivationSuccess { /* private fields */ }Expand description
Success result from run derivation.
Implementations
Sourceimpl DerivationSuccess
impl DerivationSuccess
Sourcepub fn derived(&self) -> &[RunInstance]
pub fn derived(&self) -> &[RunInstance]
Returns the newly derived run instances.
Sourcepub fn into_derived(self) -> Vec<RunInstance>
pub fn into_derived(self) -> Vec<RunInstance>
Consumes self and returns the newly derived run instances.
Sourcepub fn already_derived(&self) -> u32
pub fn already_derived(&self) -> u32
Returns the total number of runs considered derived for the task after this call.