pub struct ReadyIndex { /* private fields */ }Expand description
A view of all runs in the Ready state.
This structure provides filtering and traversal over runs that are eligible to be leased. Runs transition from Ready to Leased (or Canceled) when selected by the scheduler.
Implementations
Sourceimpl ReadyIndex
impl ReadyIndex
Sourcepub fn from_runs(runs: Vec<RunInstance>) -> Self
pub fn from_runs(runs: Vec<RunInstance>) -> Self
Creates a ready index from a vector of runs.
All runs must be in the Ready state.
Sourcepub fn runs(&self) -> &[RunInstance]
pub fn runs(&self) -> &[RunInstance]
Returns all runs in the ready index.