RunningIndex

Struct RunningIndex 

pub struct RunningIndex { /* private fields */ }
A view of all active runs (Leased and Running).

This structure provides filtering and traversal over runs that are currently in-flight. Active runs transition from Running to either:

  • RetryWait (on failure, if retries remain)
  • Completed (on success)
  • Failed (on failure, no retries remaining)
  • Canceled

Implementations

Source

impl RunningIndex

pub fn new() -> Self

Creates a new empty running index.

pub fn from_runs(runs: Vec<RunInstance>) -> Self

Creates a running index from a vector of runs.

All runs must be in the Leased or Running state.

pub fn runs(&self) -> &[RunInstance]

Returns all runs in the running index.

pub fn len(&self) -> usize

Returns the number of runs in the running index.

pub fn is_empty(&self) -> bool

Returns true if the index contains no runs.

pub fn leased(&self) -> Vec<&RunInstance>

Returns only leased runs.

pub fn executing(&self) -> Vec<&RunInstance>

Returns only currently executing runs.