pub struct PromotionResult { /* private fields */ }Expand description
Result of promoting scheduled runs to ready.
This structure contains the runs that were promoted from Scheduled to Ready and the remaining runs that are still in Scheduled state ( waiting for their scheduled_at time to pass).
Implementations
Sourceimpl PromotionResult
impl PromotionResult
Sourcepub fn promoted(&self) -> &[RunInstance]
pub fn promoted(&self) -> &[RunInstance]
Returns the runs that were promoted from Scheduled to Ready.
Sourcepub fn remaining_scheduled(&self) -> &[RunInstance]
pub fn remaining_scheduled(&self) -> &[RunInstance]
Returns the runs that remain in Scheduled state.