pub struct SelectionResult { /* private fields */ }Expand description
Result of running the default selector.
This structure contains the runs that should be selected (leased) from the ready index, in the order they should be selected.
Implementations
Sourceimpl SelectionResult
impl SelectionResult
Sourcepub fn selected(&self) -> &[RunInstance]
pub fn selected(&self) -> &[RunInstance]
Returns the runs selected for leasing, in order.
Sourcepub fn into_selected(self) -> Vec<RunInstance>
pub fn into_selected(self) -> Vec<RunInstance>
Consumes self and returns the selected runs.
Sourcepub fn remaining(&self) -> &[RunInstance]
pub fn remaining(&self) -> &[RunInstance]
Returns the runs remaining in the ready index after selection.